@@ -4,4 +4,4 @@
  * Strips HTML from the input string and returns just the text.
  * The resulting string must be freed when you're done with it.
  */
-char *htmlclean_strip_html(char *);
+char *htmlclean_strip_html(const char *);
